@@ -30,7 +30,7 @@ import (
 )
 
 const (
-	version             = "0.5.5"
+	version             = "0.5.6"
 	nsBOSH              = "urn:xmpp:alt-connections:xbosh"
 	nsC2SdTLS           = "urn:xmpp:alt-connections:tls"
 	nsC2SQuic           = "urn:xmpp:alt-connections:quic"
@@ -132,18 +132,18 @@ func main() {
 		*flagVerbose = true
 	}
 
-	// If neither IPv4 nor Ipv6 is specified we'll use both.
-	if !*flagV4 && !*flagV6 {
-		*flagV4 = true
-		*flagV6 = true
-	}
-
 	// If either IPv4 or IPv6 is specified but the verbose flag
 	// is not set, we'll just set it.
 	if !*flagVerbose && (*flagV4 || *flagV6) {
 		*flagVerbose = true
 	}
 
+	// If neither IPv4 nor Ipv6 is specified we'll use both.
+	if !*flagV4 && !*flagV6 {
+		*flagV4 = true
+		*flagV6 = true
+	}
+
 	// If DoT is enabled a resolver must be set.
 	if *flagDoT && *flagResolver == "" {
 		log.Fatal("A resolver must be specified for DoT.")
@@ -333,20 +333,20 @@ func printIP(record xmppsrv.SRV, ipv4 bool, ipv6 bool, test bool,
 					switch record.Type {
 					case "xmpp-client":
 						startTLS("client", serverName, c, tlsConfig, timeout)
-						c.Close()
+						_ = c.Close()
 					case "xmpps-client":
 						tlsConfig.NextProtos = []string{"xmpp-client"}
 						directTLS("client", serverName, c, tlsConfig, timeout)
-						c.Close()
+						_ = c.Close()
 					case "xmpp-server":
 						startTLS("server", serverName, c, tlsConfig, timeout)
-						c.Close()
+						_ = c.Close()
 					case "xmpps-server":
 						tlsConfig.NextProtos = []string{"xmpp-server"}
 						directTLS("server", serverName, c, tlsConfig, timeout)
-						c.Close()
+						_ = c.Close()
 					default:
-						c.Close()
+						_ = c.Close()
 					}
 				}
 			}
@@ -443,14 +443,14 @@ func startTLS(recordType string, serverName string, c net.Conn, tlsConfig *tls.C
 		fmt.Println("Server sent failure.")
 		return
 	}
-	_, err = c.Write([]byte(fmt.Sprintf("<starttls xmlns='%s'/>", nsStartTLS)))
+	_, err = fmt.Fprintf(c, "<starttls xmlns='%s'/>", nsStartTLS)
 	if err != nil {
 		fmt.Println(statusNOK)
 		fmt.Println(err)
 		return
 	}
-	for !(serverProceed.XMLName.Local == "proceed" &&
-		serverProceed.Xmlns == nsStartTLS) {
+	for serverProceed.XMLName.Local != "proceed" &&
+		serverProceed.Xmlns != nsStartTLS {
 		_, err = c.Read(buf)
 		if err != nil {
 			fmt.Println(statusNOK)
@@ -494,7 +494,7 @@ func startTLS(recordType string, serverName string, c net.Conn, tlsConfig *tls.C
 		}
 	} else {
 		checkCertExpiry(d)
-		d.Close()
+		_ = d.Close()
 	}
 }
 
@@ -603,7 +603,6 @@ func checkHostmeta(server string, verbose bool, ipv4 bool, ipv6 bool, c2s bool,
 		if resp.StatusCode == 404 {
 			return
 		}
-		defer resp.Body.Close()
 		body, err := io.ReadAll(resp.Body)
 		if err != nil {
 			return
@@ -645,6 +644,7 @@ func checkHostmeta(server string, verbose bool, ipv4 bool, ipv6 bool, c2s bool,
 				fmt.Printf("Unknown connection method: %s\n", link.Rel)
 			}
 		}
+		_ = resp.Body.Close()
 	}
 }
 
@@ -679,7 +679,6 @@ func checkHostmeta2(server string, verbose bool, ipv4 bool, ipv6 bool, c2s bool,
 	if resp.StatusCode == 404 {
 		return
 	}
-	defer resp.Body.Close()
 	body, err := io.ReadAll(resp.Body)
 	if err != nil {
 		return
@@ -760,7 +759,7 @@ func checkHostmeta2(server string, verbose bool, ipv4 bool, ipv6 bool, c2s bool,
 								}
 								tlsConfig.NextProtos = []string{"xmpp-client"}
 								directTLS("client", serverName, c, tlsConfig, timeout)
-								c.Close()
+								_ = c.Close()
 							}
 						}
 					}
@@ -797,7 +796,7 @@ func checkHostmeta2(server string, verbose bool, ipv4 bool, ipv6 bool, c2s bool,
 								}
 								tlsConfig.NextProtos = []string{"xmpp-server"}
 								directTLS("client", serverName, c, tlsConfig, timeout)
-								c.Close()
+								_ = c.Close()
 							}
 						}
 					}
@@ -864,6 +863,7 @@ func checkHostmeta2(server string, verbose bool, ipv4 bool, ipv6 bool, c2s bool,
 			}
 		}
 	}
+	_ = resp.Body.Close()
 }
 
 func checkBOSH(server string, target string, ipv4 bool, ipv6 bool, tlsConfig *tls.Config,
@@ -928,7 +928,6 @@ func checkBOSH(server string, target string, ipv4 bool, ipv6 bool, tlsConfig *tl
 		fmt.Println(err)
 		return
 	}
-	defer resp.Body.Close()
 	respBody, err := io.ReadAll(resp.Body)
 	if err != nil {
 		return
@@ -963,6 +962,7 @@ func checkBOSH(server string, target string, ipv4 bool, ipv6 bool, tlsConfig *tl
 		fmt.Printf("%s (%sno TLS%s)", statusNOK, colorRed, colorReset)
 	}
 	fmt.Println()
+	_ = resp.Body.Close()
 }
 
 func checkWebSocket(server string, target string, tlsConfig *tls.Config, timeout time.Duration, targetType string) {
